@@ -1,8 +1,9 @@
 ETH_CHAIN = 'ETHERIUM'
 POLYGON_CHAIN = 'POLYGON'
+BSC_CHAIN = 'BSC'
 SOLANA_CHAIN = 'SOLANA'
 
-CHAIN_OPTIONS = [ETH_CHAIN, POLYGON_CHAIN]  # SOLANA_CHAIN
+CHAIN_OPTIONS = [ETH_CHAIN, POLYGON_CHAIN, BSC_CHAIN]  # SOLANA_CHAIN
 
 ETHNET = "https://api.etherscan.io"
 POLYGONNET = "https://api.polygonscan.com"
@@ -10,6 +11,7 @@ BSCNET = "https://api.bscscan.com/"
 
 ETHERSCAN_URL = "https://etherscan.io"
 POLYSCAN_URL = "https://polygonscan.com"
+BSCSCAN_URL = "https://bscscan.com"
 
 COIN_GECHO_CHAIN_DATA = {
     ETH_CHAIN: {
@@ -26,5 +28,10 @@ COIN_GECHO_CHAIN_DATA = {
         "chain_id": "solana",
         "coin_id": "solana",
         "symbol": "sol",
-    }
+    },
+    BSC_CHAIN: {
+        "chain_id": "binancecoin",
+        "coin_id": "binancecoin",
+        "symbol": "bnb",
+    },
 }
