@@ -20,7 +20,7 @@ from tenacity import retry, stop_after_attempt, wait_fixed, retry_if_exception_t
 # code from https://towardsdatascience.com/decoding-ethereum-smart-contract-data-eed513a65f76
 
 
-from crypto_scan.configs import ETHNET, POLYGONNET, CHAIN_OPTIONS, ETH_CHAIN, POLYGON_CHAIN, ETHERSCAN_URL, POLYSCAN_URL
+from crypto_scan.configs import CHAIN_OPTIONS, ETHNET, POLYGONNET, BSCNET, ETH_CHAIN, POLYGON_CHAIN, BSC_CHAIN, ETHERSCAN_URL, POLYSCAN_URL, BSCSCAN_URL
 
 
 # decode transactions
@@ -134,11 +134,15 @@ def get_scan_url(chain: CHAIN_OPTIONS, addr: Optional[str] = None, txn: Optional
             return f"{ETHERSCAN_URL}/address/{addr}"
         elif chain == POLYGON_CHAIN:
             return f"{POLYSCAN_URL}/address/{addr}"
+        elif chain == BSC_CHAIN:
+            return f"{BSCSCAN_URL}/address/{addr}"
     else:
         if chain == ETH_CHAIN:
             return f"{ETHERSCAN_URL}/tx/{txn}"
         elif chain == POLYGON_CHAIN:
             return f"{POLYSCAN_URL}/tx/{txn}"
+        elif chain == BSC_CHAIN:
+            return f"{BSCSCAN_URL}/tx/{txn}"
 
 
 class Scan:
@@ -149,6 +153,8 @@ class Scan:
             self.url = f"{ETHNET}/api"
         elif chain == POLYGON_CHAIN:
             self.url = f"{POLYGONNET}/api"
+        elif chain == BSC_CHAIN:
+            self.url = f"{BSCNET}/api"
         self.default_parameters = {
             "apikey": self.API_KEY
         }
